-- catalogue of all skills
local skillCatalogue = {
	fightOffset = 1,
	healOffset = 8,
	buffOffset = 17,
	
	skills = {
		{
			index = "fight_1",
			name = "Swipe",
			category = "fight",
			player = true,
			description = 
				"You swipe at your opponent. Does basic damage.",
			level = 1,
			power = 60,
			cooldown = 0,
			cdLeft = 0,
			animation = 
				function(caster, target)
					local image = love.graphics.newImage("img/animation/swipe.png")
					
					local particle = love.graphics.newImage("img/particle/particle_1.png")
					local ps = love.graphics.newParticleSystem(particle, 250)
					ps:setBufferSize(2432);
					ps:setColors(255,255,255,255,255,48,13,255);
					ps:setDirection(4.6949356077778);
					ps:setOffset(0,0);
					ps:setEmissionRate(233);
					ps:setGravity(0,0);
					ps:setLifetime(-1);
					ps:setParticleLife(0.04,0.62);
					ps:setRadialAcceleration(0,0);
					ps:setRotation(0,0);
					ps:setSizes(0.55,1.85,1);
					ps:setSpeed(100,200);
					ps:setSpin(0,0);
					ps:setSpread(6.2831852);
					ps:setTangentialAcceleration(0,0);
					ps:stop();
					
					return {
						snd		= "snd/effect/damage_1.mp3",
						img 	= image, 
						anim 	= nil, 
						ps 		= nil, 
						path 	= {
							target:getPosition(), 
							{x=target:getX()+target:getW(), y=target:getY()+target:getH()}
						}, 
						len 	= .5,
						xOff	= image:getWidth()*g_sx/-2,
						yOff	= image:getHeight()*g_sy/-2
					}
				end,
			action = 
				function(caster, target)
					local miss = false
					local crit = false
					local damage = 0
					
					local missChance = math.max(0, 105 - math.floor(caster.state.curAccuracy / target.state.curEvasion * 100))
					if ai.chance(missChance) then
						miss = true
					end
					
					if not miss then
						if ai.chance(caster.state.curCritChance) then
							crit = true
						end
						
						damage = (caster.state.curAttack / target.state.curDefense) * 10
						if crit then
							damage = damage * (1 + (caster.state.curCritStrike / 10))
						end
						
						damage = ai.addVariance(damage, 10)
						damage = math.max(math.floor(damage), 0)
						hp = target.state.curHp - damage
						target.state.curHp = math.min(math.max(hp, 0), target.state.totHp)
					end
					
					return {
						category = "fight",
						result = damage,
						status = {},
						crit = crit,
						miss = miss,
						effect = nil,
						startTime = love.timer.getTime()
					}
				end,
		},
		{
			index = "fight_2",
			name = "Smoke Bomb",
			category = "fight",
			player = true,
			description = 
				"You release a smoke bomb near your opponent. Lowers accuracy for 3 turns.",
			level = 2,
			power = 80,
			cooldown = 10,
			cdLeft = 0,
			animation = 
				function(caster, target)
					local particle = love.graphics.newImage("img/particle/particle_1.png")
					local ps = love.graphics.newParticleSystem(particle, 250)
					ps:setBufferSize(1000);
					ps:setColors(0,0,0,179,77,77,77,91);
					ps:setDirection(4.7472954844444);
					ps:setEmissionRate(1000);
					ps:setGravity(0,172);
					ps:setLifetime(-1);
					ps:setParticleLife(0.2,1.6);
					ps:setRadialAcceleration(0,137);
					ps:setRotation(0.97738436444444,0.97738436444444);
					ps:setSizes(2,4,3);
					ps:setSpeed(124,174);
					ps:setSpin(200,400);
					ps:setSpread(0.69813168888889);
					ps:setTangentialAcceleration(0,0);
					ps:stop();
					
					return {
						snd		= nil,
						img		= nil, 
						anim 	= nil, 
						ps 		= ps, 
						path 	= {
							target:getFoot()
						}, 
						len 	= 2,
						xOff	= 0,
						yOff	= 0
					}
				end,
			action = 
				function(caster, target)
					local miss = false
					local crit = false
					
					local missChance = math.max(0, 105 - math.floor(caster.state.curAccuracy / target.state.curEvasion * 100))
					if ai.chance(missChance) then
						miss = true
					end
					
					if miss then
						effect = nil
					else
						effect = effectCatalogue.lookUpByIndex("condition_2")
					end
					
					return {
						category = "fight",
						result = nil,
						status = {"Blinded"},
						crit = crit,
						miss = miss,
						effect = effect,
						startTime = love.timer.getTime()
					}
				end
		},
		{
			index = "fight_3",
			name = "Bite",
			category = "fight",
			player = true,
			description = 
				"You bite your opponent. Does basic damage and lowers defense for 3 turns.",
			level = 6,
			power = 30,
			cooldown = 5,
			cdLeft = 0,
			animation = 
				function(caster, target)
					local image = love.graphics.newImage("img/animation/skillstub-sheet.png")
					local grid = anim8.newGrid(128, 128, image:getWidth(), image:getHeight())
					local animation = anim8.newAnimation('loop', grid('1-10,1'), 0.11)
					
					return {
						snd		= nil,
						img		= image, 
						anim 	= animation, 
						ps 		= nil, 
						path 	= {
							target:getMiddle()
						}, 
						len 	= 2,
						xOff	= 0,
						yOff	= 0
					}
				end,
			action =
				function(caster, target)
					local miss = false
					local crit = false
					local damage = 0
					
					local missChance = math.max(0, 105 - math.floor(caster.state.curAccuracy / target.state.curEvasion * 100))
					if ai.chance(missChance) then
						miss = true
					end
					
					if not miss then
						if ai.chance(caster.state.curCritChance) then
							crit = true
						end
						
						damage = (caster.state.curAttack / target.state.curDefense) * 8
						if crit then
							damage = damage * (1 + (caster.state.curCritStrike / 10))
						end
						
						damage = ai.addVariance(damage, 10)
						damage = math.max(math.floor(damage), 0)
						hp = target.state.curHp - damage
						target.state.curHp = math.min(math.max(hp, 0), target.state.totHp)
					end
					
					if miss then
						effect = nil
					else
						effect = effectCatalogue.lookUpByIndex("condition_3")
					end
					
					return {
						category = "fight",
						result = damage,
						status = {"Weakened"},
						crit = crit,
						miss = miss,
						effect = effect,
						startTime = love.timer.getTime()
					}
				end
		},
		{
			index = "fight_4",
			name = "Dragon Breath",
			category = "fight",
			player = true,
			description = 
				"You call upon the wrath of the dragons and channel their firey breath. Does damage for next 5 turns",
			level = 10,
			power = 30,
			cooldown = 12,
			cdLeft = 0,
			animation = 
				function(caster, target)
					local dx = target:getX() - caster:getX()
					local dy = target:getY() - caster:getY()
					local dir = math.atan2(dy, dx)
				
					local particle = love.graphics.newImage("img/particle/particle_1.png")
					local ps = love.graphics.newParticleSystem(particle, 250)
					ps:setBufferSize(2000);
					ps:setColors(226,16,49,51,255,128,0,255);
					ps:setDirection(dir);
					ps:setOffset(0,0);
					ps:setEmissionRate(600);
					ps:setGravity(0,0);
					ps:setLifetime(-1);
					ps:setParticleLife(1,1.4);
					ps:setRadialAcceleration(0,0);
					ps:setRotation(0.73303827333333,2.2863812811111);
					ps:setSizes(1.2,2,1.5);
					ps:setSpeed(439,713);
					ps:setSpin(0,0);
					ps:setSpread(0.17453292222222);
					ps:setTangentialAcceleration(0,0);
					ps:stop();
					
					return {
						snd		= "snd/effect/damage_3.mp3",
						img		= nil, 
						anim 	= nil, 
						ps 		= ps, 
						path 	= {
							caster:getMouth()
						}, 
						len 	= 3,
						xOff = 0,
						yOff = 0,
					}
				end,
			action =
				function(caster, target)
					local miss = false
					local crit = false
					local damage = 0
					
					local missChance = math.max(0, 105 - math.floor(caster.state.curAccuracy / target.state.curEvasion * 100))
					if ai.chance(missChance) then
						miss = true
					end
					
					if miss then
						effect = nil
					else
						effect = effectCatalogue.lookUpByIndex("dot_1")
					end
					
					return {
						category = "fight",
						result = nil,
						status = {"Burned"},
						crit = crit,
						miss = miss,
						effect = effect,
						startTime = love.timer.getTime()
					}
				end
		},
		{
			index = "fight_5",
			name = "Maim",
			category = "fight",
			player = true,
			description = 
				"You maim your opponent. Does basic damage and lowers speed for 5 turns.",
			level = 14,
			power = 30,
			cooldown = 12,
			cdLeft = 0,
			animation = 
				function(caster, target)
					local image = love.graphics.newImage("img/animation/skillstub-sheet.png")
					local grid = anim8.newGrid(128, 128, image:getWidth(), image:getHeight())
					local animation = anim8.newAnimation('loop', grid('1-10,1'), 0.11)
					
					return {
						snd		= nil,
						img		= image, 
						anim 	= animation, 
						ps 		= nil, 
						path 	= {
							target:getMiddle()
						}, 
						len 	= 2,
						xOff	= 0,
						yOff	= 0
					}
				end,
			action =
				function(caster, target)
					local miss = false
					local crit = false
					local damage = 0
					
					local missChance = math.max(0, 105 - math.floor(caster.state.curAccuracy / target.state.curEvasion * 100))
					if ai.chance(missChance) then
						miss = true
					end
					
					if not miss then
						if ai.chance(caster.state.curCritChance) then
							crit = true
						end
						
						damage = (caster.state.curAttack / target.state.curDefense) * 9
						if crit then
							damage = damage * (1 + (caster.state.curCritStrike / 10))
						end
						
						damage = ai.addVariance(damage, 10)
						damage = math.max(math.floor(damage), 0)
						hp = target.state.curHp - damage
						target.state.curHp = math.min(math.max(hp, 0), target.state.totHp)
					end
					
					if miss then
						effect = nil
					else
						effect = effectCatalogue.lookUpByIndex("condition_4")
					end
					
					return {
						category = "fight",
						result = damage,
						status = {"Slowed"},
						crit = crit,
						miss = miss,
						effect = effect,
						startTime = love.timer.getTime()
					}
				end
		},
		{
			index = "fight_6",
			name = "Spit",
			category = "fight",
			player = false,
			description = 
				"You spit venom at your opponent. Does damage for next 3 turns.",
			level = 2,
			power = 80,
			cooldown = 20,
			cdLeft = 0,
			animation = 
				function(caster, target)
					local particle = love.graphics.newImage("img/particle/particle_1.png")
					local ps = love.graphics.newParticleSystem(particle, 250)
					ps:setBufferSize(1000);
					ps:setColors(90,26,150,179,191,19,88,91);
					ps:setDirection(4.7472954844444);
					ps:setEmissionRate(1000);
					ps:setGravity(0,172);
					ps:setLifetime(-1);
					ps:setParticleLife(0.2,1.6);
					ps:setRadialAcceleration(0,137);
					ps:setRotation(0.97738436444444,0.97738436444444);
					ps:setSizes(2,4,3);
					ps:setSpeed(124,174);
					ps:setSpin(200,400);
					ps:setSpread(0.69813168888889);
					ps:setTangentialAcceleration(0,0);
					ps:stop();
					
					return {
						snd		= nil,
						img		= nil, 
						anim 	= nil, 
						ps 		= ps, 
						path 	= {
							target:getFoot()
						}, 
						len 	= 2,
						xOff	= 0,
						yOff	= 0
					}
				end,
			action = 
				function(caster, target)
					local miss = false
					local crit = false
					
					local missChance = math.max(0, 105 - math.floor(caster.state.curAccuracy / target.state.curEvasion * 100))
					if ai.chance(missChance) then
						miss = true
					end
					
					if miss then
						effect = nil
					else
						effect = effectCatalogue.lookUpByIndex("dot_2")
					end
					
					return {
						category = "fight",
						result = nil,
						status = {"Poisoned"},
						crit = crit,
						miss = miss,
						effect = effect,
						startTime = love.timer.getTime()
					}
				end
		},
		{
			index = "fight_7",
			name = "Aerial Kick",
			category = "fight",
			player = true,
			description = 
				"You do a spinning aerial kick. Does major damage.",
			level = 25,
			power = 60,
			cooldown = 3,
			cdLeft = 0,
			animation = 
				function(caster, target)
					local image = love.graphics.newImage("img/animation/skillstub-sheet.png")
					local grid = anim8.newGrid(128, 128, image:getWidth(), image:getHeight())
					local animation = anim8.newAnimation('loop', grid('1-10,1'), 0.11)
					
					return {
						snd		= nil,
						img		= image, 
						anim 	= animation, 
						ps 		= nil, 
						path 	= {
							target:getMiddle()
						}, 
						len 	= 2,
						xOff	= 0,
						yOff	= 0
					}
				end,
			action = 
				function(caster, target)
					local miss = false
					local crit = false
					local damage = 0
					
					local missChance = math.max(0, 105 - math.floor(caster.state.curAccuracy / target.state.curEvasion * 100))
					if ai.chance(missChance) then
						miss = true
					end
					
					if not miss then
						if ai.chance(caster.state.curCritChance) then
							crit = true
						end
						
						damage = (caster.state.curAttack / target.state.curDefense) * 25
						if crit then
							damage = damage * (1 + (caster.state.curCritStrike / 10))
						end
						
						damage = ai.addVariance(damage, 10)
						damage = math.max(math.floor(damage), 0)
						hp = target.state.curHp - damage
						target.state.curHp = math.min(math.max(hp, 0), target.state.totHp)
					end
					
					return {
						category = "fight",
						result = damage,
						status = {},
						crit = crit,
						miss = miss,
						effect = nil,
						startTime = love.timer.getTime()
					}
				end
		},
		{
			index = "fight_8",
			name = "Strike",
			category = "fight",
			player = false,
			description = 
				"Does basic damage.",
			level = 1,
			power = 60,
			cooldown = 0,
			cdLeft = 0,
			animation = 
				function(caster, target)
					local image = love.graphics.newImage("img/animation/strike.png")
					
					return {
						snd		= nil,
						img		= image, 
						anim 	= nil, 
						ps 		= nil, 
						path 	= {
							target:getMiddle()
						}, 
						len 	= 1,
						xOff	= image:getWidth()*g_sx/-2,
						yOff	= image:getHeight()*g_sy/-2
					}
				end,
			action = 
				function(caster, target)
					local miss = false
					local crit = false
					local damage = 0
					
					local missChance = math.max(0, 105 - math.floor(caster.state.curAccuracy / target.state.curEvasion * 100))
					if ai.chance(missChance) then
						miss = true
					end
					
					if not miss then
						if ai.chance(caster.state.curCritChance) then
							crit = true
						end
						
						damage = (caster.state.curAttack / target.state.curDefense) * 9
						if crit then
							damage = damage * (1 + (caster.state.curCritStrike / 10))
						end
						
						damage = ai.addVariance(damage, 10)
						damage = math.max(math.floor(damage), 0)
						hp = target.state.curHp - damage
						target.state.curHp = math.min(math.max(hp, 0), target.state.totHp)
					end
					
					return {
						category = "fight",
						result = damage,
						status = {},
						crit = crit,
						miss = miss,
						effect = nil,
						startTime = love.timer.getTime()
					}
				end
		},
		{
			index = "fight_9",
			name = "Sting",
			category = "fight",
			player = false,
			description = 
				"Does basic damage.",
			level = 1,
			power = 60,
			cooldown = 0,
			cdLeft = 0,
			animation = 
				function(caster, target)
					local image = love.graphics.newImage("img/animation/skillstub-sheet.png")
					local grid = anim8.newGrid(128, 128, image:getWidth(), image:getHeight())
					local animation = anim8.newAnimation('loop', grid('1-10,1'), 0.11)
					
					return {
						snd		= nil,
						img		= image, 
						anim 	= animation, 
						ps 		= nil, 
						path 	= {
							target:getMiddle()
						}, 
						len 	= 2,
						xOff	= 0,
						yOff	= 0
					}
				end,
			action = 
				function(caster, target)
					local miss = false
					local crit = false
					local damage = 0
					
					local missChance = math.max(0, 105 - math.floor(caster.state.curAccuracy / target.state.curEvasion * 100))
					if ai.chance(missChance) then
						miss = true
					end
					
					if not miss then
						if ai.chance(caster.state.curCritChance) then
							crit = true
						end
						
						damage = (caster.state.curAttack / target.state.curDefense) * 10
						if crit then
							damage = damage * (1 + (caster.state.curCritStrike / 10))
						end
						
						damage = ai.addVariance(damage, 10)
						damage = math.max(math.floor(damage), 0)
						hp = target.state.curHp - damage
						target.state.curHp = math.min(math.max(hp, 0), target.state.totHp)
					end
					
					return {
						category = "fight",
						result = damage,
						status = {},
						crit = crit,
						miss = miss,
						effect = nil,
						startTime = love.timer.getTime()
					}
				end
		},
		{
			index = "fight_10",
			name = "Sticky Web",
			category = "fight",
			player = false,
			description = 
				"Lowers speed for 5 turns.",
			level = 4,
			power = 60,
			cooldown = 15,
			cdLeft = 0,
			animation = 
				function(caster, target)
					local image = love.graphics.newImage("img/animation/skillstub-sheet.png")
					local grid = anim8.newGrid(128, 128, image:getWidth(), image:getHeight())
					local animation = anim8.newAnimation('loop', grid('1-10,1'), 0.11)
					
					return {
						snd		= nil,
						img		= image, 
						anim 	= animation, 
						ps 		= nil, 
						path 	= {
							target:getMiddle()
						}, 
						len 	= 2,
						xOff	= 0,
						yOff	= 0
					}
				end,
			action = 
				function(caster, target)
					local miss = false
					local crit = false
					
					if miss then
						effect = nil
					else
						effect = effectCatalogue.lookUpByIndex("condition_4")
					end
					
					return {
						category = "fight",
						result = nil,
						status = {"Slowed"},
						crit = crit,
						miss = miss,
						effect = effect,
						startTime = love.timer.getTime()
					}
				end
		},
		{
			index = "fight_11",
			name = "Peck",
			category = "fight",
			player = false,
			description = 
				"Does basic damage.",
			level = 1,
			power = 60,
			cooldown = 0,
			cdLeft = 0,
			animation = 
				function(caster, target)
					local image = love.graphics.newImage("img/animation/skillstub-sheet.png")
					local grid = anim8.newGrid(128, 128, image:getWidth(), image:getHeight())
					local animation = anim8.newAnimation('loop', grid('1-10,1'), 0.11)
					
					return {
						snd		= nil,
						img		= image, 
						anim 	= animation, 
						ps 		= nil, 
						path 	= {
							target:getMiddle()
						}, 
						len 	= 2,
						xOff	= 0,
						yOff	= 0
					}
				end,
			action = 
				function(caster, target)
					local miss = false
					local crit = false
					local damage = 0
					
					local missChance = math.max(0, 105 - math.floor(caster.state.curAccuracy / target.state.curEvasion * 100))
					if ai.chance(missChance) then
						miss = true
					end
					
					if not miss then
						if ai.chance(caster.state.curCritChance) then
							crit = true
						end
						
						damage = (caster.state.curAttack / target.state.curDefense) * 11
						if crit then
							damage = damage * (1 + (caster.state.curCritStrike / 10))
						end
						
						damage = ai.addVariance(damage, 10)
						damage = math.max(math.floor(damage), 0)
						hp = target.state.curHp - damage
						target.state.curHp = math.min(math.max(hp, 0), target.state.totHp)
					end
					
					return {
						category = "fight",
						result = damage,
						status = {},
						crit = crit,
						miss = miss,
						effect = nil,
						startTime = love.timer.getTime()
					}
				end
		},
		{
			index = "fight_12",
			name = "Strike",
			category = "fight",
			player = false,
			description = 
				"Does basic damage.",
			level = 1,
			power = 60,
			cooldown = 0,
			cdLeft = 0,
			animation = 
				function(caster, target)
					local image = love.graphics.newImage("img/animation/strike.png")
					
					return {
						snd		= nil,
						img		= image, 
						anim 	= nil, 
						ps 		= nil, 
						path 	= {
							target:getMiddle()
						}, 
						len 	= 1,
						xOff	= image:getWidth()*g_sx/-2,
						yOff	= image:getHeight()*g_sy/-2
					}
				end,
			action = 
				function(caster, target)
					local miss = false
					local crit = false
					local damage = 0
					
					local missChance = math.max(0, 105 - math.floor(caster.state.curAccuracy / target.state.curEvasion * 100))
					if ai.chance(missChance) then
						miss = true
					end
					
					if not miss then
						if ai.chance(caster.state.curCritChance) then
							crit = true
						end
						
						damage = (caster.state.curAttack / target.state.curDefense) * 13
						if crit then
							damage = damage * (1 + (caster.state.curCritStrike / 10))
						end
						
						damage = ai.addVariance(damage, 10)
						damage = math.max(math.floor(damage), 0)
						hp = target.state.curHp - damage
						target.state.curHp = math.min(math.max(hp, 0), target.state.totHp)
					end
					
					return {
						category = "fight",
						result = damage,
						status = {},
						crit = crit,
						miss = miss,
						effect = nil,
						startTime = love.timer.getTime()
					}
				end
		},
		{
			index = "heal_1",
			name = "Bandage",
			category = "heal",
			player = true,
			description = 
				"You bandage yourself up.",
			level = 1,
			power = 75,
			cooldown = 5,
			cdLeft = 0,
			animation = 
				function(caster, target)
					local particle = love.graphics.newImage("img/particle/particle_2.png")
					local ps = love.graphics.newParticleSystem(particle, 250)
					ps:setBufferSize(250);
					ps:setColors(255,255,255,255,79,179,255,255);
					ps:setDirection(4.6949356077778);
					ps:setEmissionRate(973);
					ps:setGravity(0,0);
					ps:setLifetime(-1);
					ps:setParticleLife(0.11,0.42);
					ps:setRadialAcceleration(1096,1096);
					ps:setRotation(0,0);
					ps:setSizes(0.21,0.86,1);
					ps:setSpeed(14,14);
					ps:setSpin(0,0);
					ps:setSpread(6.2831852);
					ps:setTangentialAcceleration(0,0);
					ps:stop();
					
					return {
						snd		= nil,
						img		= nil, 
						anim 	= nil, 
						ps 		= ps, 
						path 	= {
							target:getMiddle()
						}, 
						len 	= 2,
						xOff	= 0,
						yOff	= 0
					}
				end,
			action =
				function(caster, target)
					local health = math.ceil(ai.addVariance(caster.state.curIntelligence * 2.3, 10))
					target.state.curHp = math.min(target.state.curHp + health, target.state.totHp)
					
					return {
						category = "heal",
						result = health,
						status = {},
						crit = crit,
						miss = miss,
						effect = nil,
						startTime = love.timer.getTime()
					}
				end
		},
		{
			index = "heal_2",
			name = "Meditate",
			category = "heal",
			player = true,
			description = 
				"You meditate and gain an inner peace. Heals for the next 5 turns.",
			level = 15,
			power = 30,
			cooldown = 15,
			cdLeft = 0,
			animation = 
				function(caster, target)
					local particle = love.graphics.newImage("img/particle/particle_3.png")
					local ps = love.graphics.newParticleSystem(particle, 250)
					ps:setBufferSize(250);
					ps:setColors(255,255,255,255,79,179,255,255);
					ps:setDirection(4.6949356077778);
					ps:setEmissionRate(973);
					ps:setGravity(0,0);
					ps:setLifetime(-1);
					ps:setParticleLife(0.11,0.42);
					ps:setRadialAcceleration(1096,1096);
					ps:setRotation(0,0);
					ps:setSizes(0.21,0.86,1);
					ps:setSpeed(14,14);
					ps:setSpin(0,0);
					ps:setSpread(6.2831852);
					ps:setTangentialAcceleration(0,0);
					ps:stop();
					
					return {
						snd		= nil,
						img		= nil, 
						anim 	= nil, 
						ps 		= ps, 
						path 	= {
							target:getMiddle()
						}, 
						len 	= 2,
						xOff	= 0,
						yOff	= 0
					}
				end,
			action =
				function(caster, target)
					
					return {
						category = "heal",
						result = nil,
						status = {},
						crit = nil,
						miss = nil,
						effect = effectCatalogue.lookUpByIndex("hot_1"),
						startTime = love.timer.getTime()
					}
				end
		},
		{
			index = "buff_1",
			name = "Lifeblood",
			category = "buff",
			player = true,
			description = 
				"You call upon the lifeblood of the your ancestors. Raises your HP by 10%.",
			level = 1,
			power = 60,
			cooldown = 30,
			cdLeft = 0,
			animation = 
				function(caster, target)
					local particle = love.graphics.newImage("img/particle/particle_2.png")
					local ps = love.graphics.newParticleSystem(particle, 250)
					ps:setBufferSize(2911);
					ps:setColors(255,255,255,255,34,255,37,255);
					ps:setDirection(6.2831852);
					ps:setOffset(77,77);
					ps:setEmissionRate(1124);
					ps:setGravity(0,0);
					ps:setLifetime(-1);
					ps:setParticleLife(0.31,0.31);
					ps:setRadialAcceleration(0,0);
					ps:setRotation(0,0);
					ps:setSizes(0.72,1,1);
					ps:setSpeed(55,55);
					ps:setSpin(200,233);
					ps:setSpread(6.2831852);
					ps:setTangentialAcceleration(0,0);
					ps:stop();
					
					return {
						snd		= nil,
						img		= nil, 
						anim 	= nil, 
						ps 		= ps, 
						path 	= {
							target:getMiddle()
						}, 
						len 	= 2,
						xOff	= 0,
						yOff	= 0
					}
				end,
			action =
				function(caster, target)
					effect = effectCatalogue.lookUpByIndex("boon_2")
					
					return {
						category = "buff",
						result = nil,
						status = {},
						crit = nil,
						miss = nil,
						effect = effect,
						startTime = love.timer.getTime()
					}
				end
		},
		{
			index = "buff_2",
			name = "Flex",
			category = "buff",
			player = true,
			description = 
				"You flex your muscles and build up strength. Raises your Attack by 20%.",
			level = 2,
			power = 60,
			cooldown = 15,
			cdLeft = 0,
			animation = 
				function(caster, target)
					local particle = love.graphics.newImage("img/particle/particle_2.png")
					local ps = love.graphics.newParticleSystem(particle, 250)
					ps:setBufferSize(2911);
					ps:setColors(255,255,255,255,34,255,37,255);
					ps:setDirection(6.2831852);
					ps:setOffset(77,77);
					ps:setEmissionRate(1124);
					ps:setGravity(0,0);
					ps:setLifetime(-1);
					ps:setParticleLife(0.31,0.31);
					ps:setRadialAcceleration(0,0);
					ps:setRotation(0,0);
					ps:setSizes(0.72,1,1);
					ps:setSpeed(55,55);
					ps:setSpin(200,233);
					ps:setSpread(6.2831852);
					ps:setTangentialAcceleration(0,0);
					ps:stop();
					
					return {
						snd		= nil,
						img		= nil, 
						anim 	= nil, 
						ps 		= ps, 
						path 	= {
							target:getMiddle()
						}, 
						len 	= 2,
						xOff	= 0,
						yOff	= 0
					}
				end,
			action =
				function(caster, target)
					return {
						category = "buff",
						result = nil,
						status = {"Flexing"},
						crit = nil,
						miss = nil,
						effect = effectCatalogue.lookUpByIndex("boon_3"),
						startTime = love.timer.getTime()
					}
				end
		},
		{
			index = "buff_3",
			name = "Brace",
			category = "buff",
			player = true,
			description = 
				"You brace yourself for attack. Raises your Defense by 20%.",
			level = 5,
			power = 60,
			cooldown = 15,
			cdLeft = 0,
			animation = 
				function(caster, target)
					local particle = love.graphics.newImage("img/particle/particle_2.png")
					local ps = love.graphics.newParticleSystem(particle, 250)
					ps:setBufferSize(2911);
					ps:setColors(255,255,255,255,34,255,37,255);
					ps:setDirection(6.2831852);
					ps:setOffset(77,77);
					ps:setEmissionRate(1124);
					ps:setGravity(0,0);
					ps:setLifetime(-1);
					ps:setParticleLife(0.31,0.31);
					ps:setRadialAcceleration(0,0);
					ps:setRotation(0,0);
					ps:setSizes(0.72,1,1);
					ps:setSpeed(55,55);
					ps:setSpin(200,233);
					ps:setSpread(6.2831852);
					ps:setTangentialAcceleration(0,0);
					ps:stop();
					
					return {
						snd		= nil,
						img		= nil, 
						anim 	= nil, 
						ps 		= ps, 
						path 	= {
							target:getMiddle()
						}, 
						len 	= 2,
						xOff	= 0,
						yOff	= 0
					}
				end,
			action =
				function(caster, target)
					return {
						category = "buff",
						result = nil,
						status = {"Bracing"},
						crit = nil,
						miss = nil,
						effect = effectCatalogue.lookUpByIndex("boon_4"),
						startTime = love.timer.getTime()
					}
				end
		},
		{
			index = "buff_4",
			name = "Energize",
			category = "buff",
			player = true,
			description = 
				"You reach deep within and find a hidden store of energy. Raises your Speed by 50%.",
			level = 9,
			power = 60,
			cooldown = 20,
			cdLeft = 0,
			animation = 
				function(caster, target)
					local particle = love.graphics.newImage("img/particle/particle_2.png")
					local ps = love.graphics.newParticleSystem(particle, 250)
					ps:setBufferSize(2911);
					ps:setColors(255,255,255,255,34,255,37,255);
					ps:setDirection(6.2831852);
					ps:setOffset(77,77);
					ps:setEmissionRate(1124);
					ps:setGravity(0,0);
					ps:setLifetime(-1);
					ps:setParticleLife(0.31,0.31);
					ps:setRadialAcceleration(0,0);
					ps:setRotation(0,0);
					ps:setSizes(0.72,1,1);
					ps:setSpeed(55,55);
					ps:setSpin(200,233);
					ps:setSpread(6.2831852);
					ps:setTangentialAcceleration(0,0);
					ps:stop();
					
					return {
						snd		= nil,
						img		= nil, 
						anim 	= nil, 
						ps 		= ps, 
						path 	= {
							target:getMiddle()
						}, 
						len 	= 2,
						xOff	= 0,
						yOff	= 0
					}
				end,
			action =
				function(caster, target)
					return {
						category = "buff",
						result = nil,
						status = {"Energized"},
						crit = nil,
						miss = nil,
						effect = effectCatalogue.lookUpByIndex("boon_5"),
						startTime = love.timer.getTime()
					}
				end
		},
		{
			index = "buff_5",
			name = "Concentrate",
			category = "buff",
			player = true,
			description = 
				"You concentrate intensely on your enemy. Raises your Accuracy by 20%.",
			level = 12,
			power = 60,
			cooldown = 15,
			cdLeft = 0,
			animation = 
				function(caster, target)
					local particle = love.graphics.newImage("img/particle/particle_2.png")
					local ps = love.graphics.newParticleSystem(particle, 250)
					ps:setBufferSize(2911);
					ps:setColors(255,255,255,255,34,255,37,255);
					ps:setDirection(6.2831852);
					ps:setOffset(77,77);
					ps:setEmissionRate(1124);
					ps:setGravity(0,0);
					ps:setLifetime(-1);
					ps:setParticleLife(0.31,0.31);
					ps:setRadialAcceleration(0,0);
					ps:setRotation(0,0);
					ps:setSizes(0.72,1,1);
					ps:setSpeed(55,55);
					ps:setSpin(200,233);
					ps:setSpread(6.2831852);
					ps:setTangentialAcceleration(0,0);
					ps:stop();
					
					return {
						snd		= nil,
						img		= nil, 
						anim 	= nil, 
						ps 		= ps, 
						path 	= {
							target:getMiddle()
						}, 
						len 	= 2,
						xOff	= 0,
						yOff	= 0
					}
				end,
			action =
				function(caster, target)
					return {
						category = "buff",
						result = nil,
						status = {"Concentrating"},
						crit = nil,
						miss = nil,
						effect = effectCatalogue.lookUpByIndex("boon_6"),
						startTime = love.timer.getTime()
					}
				end
		},
		{
			index = "buff_6",
			name = "Ninja Mode",
			category = "buff",
			player = true,
			description = 
				"You go into ninja mode. Raises your Evasion by 50%.",
			level = 16,
			power = 60,
			cooldown = 20,
			cdLeft = 0,
			animation = 
				function(caster, target)
					local particle = love.graphics.newImage("img/particle/particle_2.png")
					local ps = love.graphics.newParticleSystem(particle, 250)
					ps:setBufferSize(2911);
					ps:setColors(255,255,255,255,34,255,37,255);
					ps:setDirection(6.2831852);
					ps:setOffset(77,77);
					ps:setEmissionRate(1124);
					ps:setGravity(0,0);
					ps:setLifetime(-1);
					ps:setParticleLife(0.31,0.31);
					ps:setRadialAcceleration(0,0);
					ps:setRotation(0,0);
					ps:setSizes(0.72,1,1);
					ps:setSpeed(55,55);
					ps:setSpin(200,233);
					ps:setSpread(6.2831852);
					ps:setTangentialAcceleration(0,0);
					ps:stop();
					
					return {
						snd		= nil,
						img		= nil, 
						anim 	= nil, 
						ps 		= ps, 
						path 	= {
							target:getMiddle()
						}, 
						len 	= 2,
						xOff	= 0,
						yOff	= 0
					}
				end,
			action =
				function(caster, target)
					return {
						category = "buff",
						result = nil,
						status = {"Ninja Mode"},
						crit = nil,
						miss = nil,
						effect = effectCatalogue.lookUpByIndex("boon_7"),
						startTime = love.timer.getTime()
					}
				end
		},
	}
}

function skillCatalogue.lookUp(i)
	return deepCopy(skillCatalogue.skills[i])
end

function skillCatalogue.lookUpByIndex(index)
	for k,v in pairs(skillCatalogue.skills) do
		if v.index == index then
			return deepCopy(v)
		end
	end
end

function skillCatalogue.getSkillsByLevel(lvl)
	local skills = {}
	for k,v in pairs(skillCatalogue.skills) do
		if v.level <= lvl then
			table.insert(skills, deepCopy(v))
		end
	end
	
	return skills
end

-- save table of skill names and cooldowns
function skillCatalogue.saveSkills(skills)
	local saveSkills = {}
	
	for i,v in ipairs(skills) do
		table.insert(saveSkills, v.index)
	end
	
	return saveSkills
end

-- load skills based on name
function skillCatalogue.loadSkills(skills)
	local loadSkills = {}
	
	for i,v in pairs(skills) do
		local skill = skillCatalogue.lookUpByIndex(v)
		table.insert(loadSkills, skill)
	end
	
	return loadSkills
end

return skillCatalogue