Follower = class('Follower')

local _location = {}
local _path = {}
local _distance = 0
local _duration = 0
local _speed = 0
local _xOffset = 0
local _yOffset = 0

local _from = {}
local _to = {}
local _iter = 1
local _goalFound = nil


local _getDistance = function(self, path)
	local d = 0
	
	for i=2,#path do
		local x1 = path[i-1].x
		local y1 = path[i-1].y
		local x2 = path[i].x
		local y2 = path[i].y
		
		d = d + math.sqrt(math.pow(x2-x1, 2) + (math.pow(y2-y1, 2)))
	end
	
	return d
end

local _copy = function(self, t)
    local lookup_table = {}
    local function _copy(t)
        if type(t) ~= "table" then
            return t
        elseif lookup_table[t] then
            return lookup_table[t]
        end
        local new_table = {}
        lookup_table[t] = new_table
        for index, value in pairs(t) do
            new_table[_copy(index)] = _copy(value)
        end
        return setmetatable(new_table, getmetatable(t))
    end
    return _copy(t)
end

local _reverse = function(self, t)
    local newT = {}

    for i,v in ipairs (t) do
        newT[#t-i+1] = v
    end

    return newT
end

local _initPath = function(self)
	_iter = 1
	
	if #_path > 1 then
	
		_from = _path[_iter]
		_to = _path[_iter+1]
		
		_location = _path[_iter]
		_goalFound = false
		
	elseif #_path == 1 then
	
		_location = _path[_iter]
		_goalFound = true
		
	else
	
		_location = {x=0, y=0}
		_goalFound = true
		
	end
end

function Follower:initialize(path, duration, xOffset, yOffset)
	_path 		= _copy(self, path) 			or _path
	_distance 	= _getDistance(self, _path) 	or _distance
	_duration 	= duration 						or _duration
	_speed 		= _distance/_duration			or _speed
	_xOffset 	= xOffset 						or _xOffset
	_yOffset 	= yOffset						or _yOffset
	
	_initPath(self)
end

function Follower:update(dt)

	if not self:goalFound() then
		if _from then
			if _to then
				
				local dx = _to.x - _from.x
				local dy = _to.y - _from.y
				
				local dx2 = math.pow(dx, 2)
				local dy2 = math.pow(dy, 2)
				
				local x_sign = dx / math.abs(dx)
				local y_sign = dy / math.abs(dy)
				
				local dd = _speed * dt
				
				local dd2 = math.pow(dd, 2)
			
				_location.x = _location.x + x_sign * math.sqrt(dd2 / (dx2 + dy2) * dx2)
				_location.y = _location.y + y_sign * math.sqrt(dd2 / (dx2 + dy2) * dy2)
				
				if _location.x <= _to.x + (dd*1.1) then
					if _location.x >= _to.x - (dd*1.1) then
						if _location.y <= _to.y + (dd*1.1) then
							if _location.y >= _to.y - (dd*1.1) then
								_iter = _iter + 1
								
								_location = _path[_iter]
								
								if _iter == #_path then							
									_goalFound = true
								else
									_from = _path[_iter]
									_to = _path[_iter+1]
								end
								
							end
						end
					end
				end
			end
		end
	end
	
end

function Follower:getX()
	return _location.x + _xOffset
end

function Follower:getY()
	return _location.y + _yOffset
end

function Follower:goalFound()
	return _goalFound
end
