function love.load()
	g_version = "0.2.7"
	g_profile_version = "2"

	-- load requried libraries
	require("lib/loveframes/init")
	require("lib/middleclass")
	require("lib/tlfres")
	require("lib/tserial")	
	require("lib/tesound")
	require("lib/util")
	require("lib/follower")
	anim8 = require("lib/anim8")
	
	-- load required game files
	require("toon")
	ai					= require("ai")
	effectCatalogue		= require("cat/effectcatalogue")
	skillCatalogue		= require("cat/skillcatalogue")
	mobCatalogue		= require("cat/mobcatalogue")
	mainScreen			= require("scrn/mainscreen")
	newProfileScreen	= require("scrn/newprofilescreen")
	loadProfileScreen	= require("scrn/loadprofilescreen")
	optionScreen		= require("scrn/optionscreen")
	storyScreen			= require("scrn/storyscreen")
	badgerScreen		= require("scrn/badgerscreen")
	skillScreen			= require("scrn/skillscreen")
	battleTranScreen	= require("scrn/battletranscreen")
	battleScreen		= require("scrn/battlescreen")
	winScreen			= require("scrn/winscreen")
	loseScreen			= require("scrn/losescreen")
	fleeScreen			= require("scrn/fleescreen")
	
	-- set write directory
	love.filesystem.setIdentity("bb")
	
	-- load fonts
	g_font_sansumi_12		= love.graphics.newFont("font/Sansumi-Bold.ttf", 12)
	g_font_sansumi_16		= love.graphics.newFont("font/Sansumi-Bold.ttf", 16)
	g_font_sansumi_24		= love.graphics.newFont("font/Sansumi-Bold.ttf", 24)
	g_font_dimbo_12			= love.graphics.newFont("font/Dimbo Italic.ttf", 12)
	g_font_dimbo_15			= love.graphics.newFont("font/Dimbo Italic.ttf", 15)
	g_font_dimbo_16 		= love.graphics.newFont("font/Dimbo Italic.ttf", 16)
	g_font_dimbo_18			= love.graphics.newFont("font/Dimbo Italic.ttf", 18)
	g_font_dimbo_20			= love.graphics.newFont("font/Dimbo Italic.ttf", 20)
	g_font_dimbo_24			= love.graphics.newFont("font/Dimbo Italic.ttf", 24)
	g_font_dimbo_26			= love.graphics.newFont("font/Dimbo Italic.ttf", 26)
	g_font_dimbo_30			= love.graphics.newFont("font/Dimbo Italic.ttf", 30)
	g_font_dimbo_36			= love.graphics.newFont("font/Dimbo Italic.ttf", 36)
	g_font_dimbo_38			= love.graphics.newFont("font/Dimbo Italic.ttf", 38)
	g_font_dimbo_40			= love.graphics.newFont("font/Dimbo Italic.ttf", 40)
	g_font_dimbo_48			= love.graphics.newFont("font/Dimbo Italic.ttf", 48)
	g_font_dimbo_60			= love.graphics.newFont("font/Dimbo Italic.ttf", 60)
	g_font_dimbo_78			= love.graphics.newFont("font/Dimbo Italic.ttf", 78)
	g_font_dimbo_80			= love.graphics.newFont("font/Dimbo Italic.ttf", 80)
	g_font_dimbo_100		= love.graphics.newFont("font/Dimbo Italic.ttf", 100)
	
	-- store default screen dimensions in global variables
	g_w_default = 1920
	g_h_default = 1080
	
	-- store screen dimensions in global variables
	g_w = love.graphics.getWidth()
	g_h = love.graphics.getHeight()
	
	-- store scale factors in global variables
	g_sx = g_w / g_w_default
	g_sy = g_h / g_h_default

	-- set global values
	love.graphics.setBackgroundColor(50, 50, 50, 255)
	love.keyboard.setKeyRepeat(0.5, 0.05)
	
	-- initialize current screen to main screen
	currentScreen = mainScreen
	currentScreen.load()
end

function love.keypressed(key, unicode)
	currentScreen.keypressed(key, unicode)
	loveframes.keypressed(key, unicode)
end

function love.keyreleased(key, unicode)
	currentScreen.keyreleased(key)
	loveframes.keyreleased(key)
end

function love.mousepressed(x, y, button)
    currentScreen.mousepressed(x, y, button)
	loveframes.mousepressed(x, y, button)
end

function love.mousereleased(x, y, button)
    currentScreen.mousereleased(x, y, button)
	loveframes.mousereleased(x, y, button)
end

function love.update(dt)
	currentScreen.update(dt)
	loveframes.update(dt)
	TEsound.cleanup()
end

function love.draw()
	love.graphics.setColor(255, 255, 255, 255)
	
	currentScreen.draw()
	loveframes.draw()
	
	love.graphics.setColor(0,0,0,255)
	love.graphics.print(love.timer.getFPS(), 10, 10)
	love.graphics.setColor(255, 255, 255, 255)
end

function love.focus(f)
	if f then
	
	else
	
	end
end

function love.quit()
	-- save game if player has been initialized
	if player then
		saveGame(player)
	end
end

-- load profiles from file
function loadProfiles()
	if love.filesystem.exists("profiles_" .. g_profile_version) then
		local file = love.filesystem.newFile("profiles_" .. g_profile_version)
		file:open('r')
		local data = file:read()
		file:close()
		
		if TSerial.unpack(data) == "BAD_TABLE" then
			local backup = love.filesystem.newFile("profiles.bkp")
			backup:open('w')
			backup:write(data)
			backup:close()
			love.filesystem.remove("profiles_" .. g_profile_version)
			print("Profiles backed up to profiles.bkp and removed")
		else
			return TSerial.unpack(data)
		end
	end
end

-- initialize values for a new game
function newGame(name)
	local newPlayer = {}
	
	if name == "Viking Badger 7" then
		newPlayer	= {
			name 			= name,
			stats 			= {
				level 			= 99,
				hp 				= 9999,
				attack 			= 10,
				defense 		= 10,
				intelligence 	= 10,
				speed 			= 5,
				accuracy 		= 10,
				evasion 		= 10,
				critChance 		= 5,
				critStrike 		= 5
			},
			state 			= {
			},
			progress 		= {	
				curXp			= 0,
				totXp 			= 0,
				curSp			= 150,
				totSp			= 150,
				xpToLvl 		= 0,
				nextMob 		= 50,
				mobsKilled 		= 0
			},
			skills 			= skillCatalogue.loadSkills({"fight_1", "heal_1", "buff_1"}),
			activeEffects 	= {}
		}
	else
		newPlayer	= {
			name 			= name,
			stats 			= {
				level 			= 1,
				hp 				= 100,
				attack 			= 10,
				defense 		= 10,
				intelligence 	= 10,
				speed 			= 5,
				accuracy 		= 10,
				evasion 		= 10,
				critChance 		= 5,
				critStrike 		= 5
			},
			state 			= {
			},
			progress 		= {	
				curXp			= 0,
				totXp 			= 0,
				curSp			= 0,
				totSp			= 0,
				xpToLvl 		= 500,
				nextMob 		= 1,
				mobsKilled 		= 0
			},
			skills 			= skillCatalogue.loadSkills({"fight_1", "heal_1", "buff_1"}),
			activeEffects 	= {}
		}
	end
	
	player = Player:new(newPlayer)
	
	saveGame(player)
end

-- save all relevant data to file
function saveGame(toon)
	local profiles = loadProfiles() or {}
	
	profiles[toon.name] = {
		name 			= toon.name,
		stats 			= {
			level 			= toon.stats.level,
			hp 				= toon.stats.hp,
			attack 			= toon.stats.attack,
			defense 		= toon.stats.defense,
			intelligence 	= toon.stats.intelligence,
			speed 			= toon.stats.speed,
			accuracy 		= toon.stats.accuracy,
			evasion 		= toon.stats.evasion,
			critChance 		= toon.stats.critChance,
			critStrike 		= toon.stats.critStrike
		},
		state 			= {
		},
		progress 		= {
			curXp 			= toon.progress.curXp,
			totXp 			= toon.progress.totXp,
			curSp			= toon.progress.curSp,
			totSp			= toon.progress.totSp,
			xpToLvl 		= toon.progress.xpToLvl,
			nextMob 		= toon.progress.nextMob,
			mobsKilled 		= toon.progress.mobsKilled
		},
		skills 			= skillCatalogue.saveSkills(toon.skills),
		activeEffects 	= {} --effectCatalogue.saveEffects(toon.activeEffects)
	}
	
	local data = TSerial.pack(profiles)
	
	local file = love.filesystem.newFile("profiles" .. "_" .. g_profile_version)
	file:open('w')
	file:write(data)
	file:close()
end

-- load all relevant data from file
function loadGame(name)
	local profiles = loadProfiles()
	
	if profiles[name] then
		local profile = profiles[name]
		profile.skills 			= skillCatalogue.loadSkills(profile.skills)
		profile.activeEffects 	= {} --effectCatalogue.loadEffects(profile.activeEffects)
		
		-- initialize player
		player = Player:new(profile)
	end
end

-- change screen on request
function changeScreen(newScreen, args)
	currentScreen.unload()
	currentScreen = newScreen
	currentScreen.load(args)
end
