local battleScreen = {}
	
function battleScreen.load(args)
	love.graphics.setPixelEffect()
	
	-- initialize enemy
	enemy = Enemy:new(args[1])
	
	-- initialize character positions
	player:initPosition()
	if (args[1] % 5) == 0 then
		enemy:initPosition(true)
	else
		enemy:initPosition(false)
	end
	
	-- load images
	local mobNumber = args[1] % 5
	if mobNumber == 1 then
		bg = love.graphics.newImage("img/backdrop/background1.jpg")
	elseif mobNumber == 2 then
		bg = love.graphics.newImage("img/backdrop/background2.jpg")
	elseif mobNumber == 3 then
		bg = love.graphics.newImage("img/backdrop/background3.jpg")
	elseif mobNumber == 4 then
		bg = love.graphics.newImage("img/backdrop/background4.jpg")
	else
		bg = love.graphics.newImage("img/backdrop/background5.jpg")		
	end
	arrow = love.graphics.newImage("img/other/arrow.png")
	
	-- start music
	if (args[1] % 5) == 0 then
		TEsound.playLooping("snd/music/battle_boss.mp3", "battleMusic")
	else
		TEsound.playLooping("snd/music/battle_mob.mp3", "battleMusic")
	end
	TEsound.volume("all", .2)
	
	-- initialize GUI
	battleScreen.initTurns()
	battleScreen.initBattleMenu()
	battleScreen.changeMenuState("battle")
	
	-- initialize length of time to draw skill reports to 2 seconds
	reportLength = 3
	
	battleStartTime = love.timer.getTime()
	battleIntro = true
	battleScreen.disableBattleMenu()
end

function battleScreen.unload()
	TEsound.stop("battleMusic")

	loveframes.util.RemoveAll()
	
	player:refreshStatus()
	enemy:refreshStatus()
end

function battleScreen.keypressed(key, unicode)
end

function battleScreen.keyreleased(key, unicode)
end

function battleScreen.mousepressed(x, y, button)
end

function battleScreen.mousereleased(x, y, button)
end

function battleScreen.update(dt)
	if battleIntro and love.timer.getTime() > battleStartTime + 3 then
		battleScreen.nextTurn()
		battleIntro = false
	end
	
	if not battleIntro then
		player:update(dt)
		enemy:update(dt)
		
		-- if a character is in action
		if activeToon.inAction then
			local s = activeToon.currentSkill
			
			if s.image then
				if s.animation then
					s.animation:update(dt)
				end
				if s.follower then
					s.follower:update(dt)
				end
			end
			if s.particles then
				s.particles:start()
				s.particles:update(dt)
			end
			
			if love.timer.getTime() - s.start >= s.length then
				if s.sound then
					TEsound.stop("skillSound")
				end
				
				if s.particles then
					s.particles:stop()
				end
				
				skillResult = s.action(activeToon, s.target)
				if skillResult.effect then
					s.target:addEffect(activeToon, skillResult.effect)
				end
				
				effectResult = activeToon:updateStatus()
				
				activeToon.inAction = false
				activeToon.reporting = true
			end
		elseif activeToon.reporting then
			if love.timer.getTime() - skillResult.startTime >= reportLength then
				activeToon.reporting = false
				activeToon.currentSkill = {}
				iRemoveAll(skillResult.status)
				skillResult = nil
				effectResult = nil
				reportLength = 3
				
				battleScreen.updateBattleMenu()
				battleScreen.nextTurn()
			end
		end
	end
end

-- code to draw every frame
function battleScreen.draw()
	-- draw background
	love.graphics.draw(bg, 0, 0, 0, g_sx, g_sy)
	
	player:drawSprite()
	enemy:drawSprite()
	
	player:drawAction()
	enemy:drawAction()
	
	player:drawReport()
	enemy:drawReport()
	
	player:drawHUD()
	enemy:drawHUD()
	
	love.graphics.setColor(255, 255, 255, 255)
	love.graphics.setFont(g_font_dimbo_20)
	
	if battleIntro then
		love.graphics.setColor(255, 204, 11, 255)
		love.graphics.setFont(g_font_dimbo_100)
		love.graphics.printf("Begin Battle!", 0, g_h/2-100, g_w, "center")
	end
end

-- initialize turn schedule
function battleScreen.initTurns()
	playerTurnCount = 0
	enemyTurnCount = 0
	
	turns = {}
	
	turnSchedule = {
		loveframes.Create("button"),
		loveframes.Create("button"),
		loveframes.Create("button"),
		loveframes.Create("button"),
		loveframes.Create("button")
	}
	
	local buttonY = 2
	for i,v in ipairs(turnSchedule) do
		v:SetPos(g_w - 150, buttonY)		
		v:SetSize(148, 50)
		v:SetEnabled(false)
		
		buttonY = buttonY + 52
	end
	
	battleScreen.updateTurns(ai.addVariance(player.state.curSpeed / enemy.state.curSpeed, 3))
	table.remove(turns, 1)
end

-- initialize battle menu
function battleScreen.initBattleMenu()
	
	battleMenu = {
		loveframes.Create("button"),
		loveframes.Create("button"),
		loveframes.Create("button"),
		loveframes.Create("button")
	}
	
	battleMenu[1]:SetText("Fight")
	battleMenu[1].OnClick = function() battleScreen.changeMenuState("fight") end
	battleMenu[2]:SetText("Heal")
	battleMenu[2].OnClick = function() battleScreen.changeMenuState("heal") end
	battleMenu[3]:SetText("Buff")
	battleMenu[3].OnClick = function() battleScreen.changeMenuState("buff") end
	battleMenu[4]:SetText("Flee")
	battleMenu[4].OnClick = function() changeScreen(fleeScreen) end
	
	local buttonY = -140
	for i,v in ipairs(battleMenu) do
		v:SetPos(3, g_h + buttonY)		
		v:SetSize(100, 32)
		
		buttonY = buttonY + 34
	end
	
	fightMenu = {}
	healMenu = {}
	buffMenu = {}
	
	local s_fightMenu = {}
	local s_healMenu = {}
	local s_buffMenu = {}
	
	for k,v in pairs(player.skills) do
		local button = loveframes.Create("button")
		local tooltip = loveframes.Create("tooltip")
		
		button:SetText(v.name)
		button.OnClick = 
			function()
				tooltip:Remove()
				battleScreen.changeMenuState("battle")
				battleScreen.playerTurn(v)
			end
			
		tooltip:SetObject(button)
		tooltip:SetFollowCursor(false)
		tooltip:SetOffsets(20, -4)
		tooltip:SetPadding(10)
		tooltip:SetTextMaxWidth(220)
		tooltip:SetFont(g_font_sansumi_12)
		tooltip:SetText(v.description)
		
		if v.category == "fight" then
			fightMenu[v.index] = button
			table.insert(s_fightMenu, fightMenu[v.index])
		elseif v.category == "heal" then
			healMenu[v.index] = button
			table.insert(s_healMenu, healMenu[v.index])
		elseif v.category == "buff" then
			buffMenu[v.index] = button
			table.insert(s_buffMenu, buffMenu[v.index])
		end
	end
	
	fightMenu["Back"] = loveframes.Create("button")
	fightMenu["Back"]:SetText("Back")
	fightMenu["Back"].OnClick = function() battleScreen.changeMenuState("battle") end
	table.insert(s_fightMenu, fightMenu["Back"])
	
	healMenu["Back"] = loveframes.Create("button")
	healMenu["Back"]:SetText("Back")
	healMenu["Back"].OnClick = function() battleScreen.changeMenuState("battle") end
	table.insert(s_healMenu, healMenu["Back"])
	
	buffMenu["Back"] = loveframes.Create("button")
	buffMenu["Back"]:SetText("Back")
	buffMenu["Back"].OnClick = function() battleScreen.changeMenuState("battle") end
	table.insert(s_buffMenu, buffMenu["Back"])
	
	buttonY = #s_fightMenu * -52 - 96
	for i,v in ipairs(s_fightMenu) do
		v:SetPos(50, g_h + buttonY)		
		v:SetSize(140, 50)
	
		buttonY = buttonY + 52
	end
	
	buttonY = #s_healMenu * -52 - 64
	for i,v in ipairs(s_healMenu) do
		v:SetPos(50, g_h + buttonY)	
		v:SetSize(140, 50)
	
		buttonY = buttonY + 52
	end
	
	buttonY = #s_buffMenu * -52 - 32
	for i,v in ipairs(s_buffMenu) do
		v:SetPos(50, g_h + buttonY)		
		v:SetSize(140, 50)
	
		buttonY = buttonY + 52
	end
	
	battleScreen.updateBattleMenu()
end

function battleScreen.updateTurns(speedRatio)
	while #turns < 5 do
		if (playerTurnCount / enemyTurnCount) < speedRatio then
			playerTurnCount = playerTurnCount + 1
			table.insert(turns, player)
			turnSchedule[#turns]:SetText(player.name)
		elseif (playerTurnCount / enemyTurnCount) > speedRatio then
			enemyTurnCount = enemyTurnCount + 1
			table.insert(turns, enemy)
			turnSchedule[#turns]:SetText(enemy.name)
		elseif speedRatio > 1 then
			playerTurnCount = playerTurnCount + 1
			table.insert(turns, player)
			turnSchedule[#turns]:SetText(player.name)
		elseif speedRatio < 1 then
			enemyTurnCount = enemyTurnCount + 1
			table.insert(turns, enemy)
			turnSchedule[#turns]:SetText(enemy.name)
		else
			if turns[#turns] == player then
				enemyTurnCount = enemyTurnCount + 1
				table.insert(turns, enemy)
				turnSchedule[#turns]:SetText(enemy.name)
			else
				playerTurnCount = playerTurnCount + 1
				table.insert(turns, player)
				turnSchedule[#turns]:SetText(player.name)
			end
		end
	end
end

function battleScreen.updateBattleMenu()
	for k,v in pairs(player.skills) do
		if v.cdLeft > 0 then
			if v.category == "fight" then
				fightMenu[v.index]:SetEnabled(false)
				fightMenu[v.index]:SetText(v.name .. " (" .. v.cdLeft .. ")")
			elseif v.category == "heal" then
				healMenu[v.index]:SetEnabled(false)
				healMenu[v.index]:SetText(v.name .. " (" .. v.cdLeft .. ")")
			elseif v.category == "buff" then
				buffMenu[v.index]:SetEnabled(false)
				buffMenu[v.index]:SetText(v.name .. " (" .. v.cdLeft .. ")")
			end
		else
			if v.category == "fight" then
				fightMenu[v.index]:SetEnabled(true)
				fightMenu[v.index]:SetText(v.name)
			elseif v.category == "heal" then
				healMenu[v.index]:SetEnabled(true)
				healMenu[v.index]:SetText(v.name)
			elseif v.category == "buff" then
				buffMenu[v.index]:SetEnabled(true)
				buffMenu[v.index]:SetText(v.name)
			end
		end
	end
end

function battleScreen.enableBattleMenu()
	for i,v in ipairs(battleMenu) do
		v:SetEnabled(true)
	end
end

function battleScreen.disableBattleMenu()
	for i,v in ipairs(battleMenu) do
		v:SetEnabled(false)
	end
end

-- change menu to requested state
function battleScreen.changeMenuState(menuState)
	
	if menuState == "battle" then
		for i,v in ipairs(battleMenu) do v:SetEnabled(true) end
		for k,v in pairs(fightMenu) do v:SetVisible(false) end
		for k,v in pairs(healMenu) do v:SetVisible(false) end
		for k,v in pairs(buffMenu) do v:SetVisible(false) end
	elseif menuState == "fight" then
		for i,v in ipairs(battleMenu) do v:SetEnabled(false) end
		for k,v in pairs(fightMenu) do v:SetVisible(true) end
		for k,v in pairs(healMenu) do v:SetVisible(false) end
		for k,v in pairs(buffMenu) do v:SetVisible(false) end
	elseif menuState == "heal" then
		for i,v in ipairs(battleMenu) do v:SetEnabled(false) end
		for k,v in pairs(fightMenu) do v:SetVisible(false) end
		for k,v in pairs(healMenu) do v:SetVisible(true) end
		for k,v in pairs(buffMenu) do v:SetVisible(false) end
	elseif menuState == "buff" then
		for i,v in ipairs(battleMenu) do v:SetEnabled(false) end
		for k,v in pairs(fightMenu) do v:SetVisible(false) end
		for k,v in pairs(healMenu) do v:SetVisible(false) end
		for k,v in pairs(buffMenu) do v:SetVisible(true) end
	end
end

-- go to the next turn
function battleScreen.nextTurn()
	
	-- check for win/loss
	if player.state.curHp == 0 then
		changeScreen(loseScreen)
		return
	elseif enemy.state.curHp == 0 then
		changeScreen(winScreen, {enemy})
		return
	end
	
	table.remove(turns, 1)
	activeToon = turns[1]
	turnSchedule[1]:SetText(activeToon.name)
	for i=2,#turns do
		turnSchedule[i]:SetText(turns[i].name)
	end
	
	battleScreen.updateTurns(ai.addVariance(player.state.curSpeed / enemy.state.curSpeed, 3))
	
	if activeToon == enemy then	
		battleScreen.enemyTurn()
	else
		battleScreen.enableBattleMenu()
	end
end

-- player turn
function battleScreen.playerTurn(skill)
	battleScreen.disableBattleMenu()
	
	player.inAction = true
	
	skill.cdLeft = skill.cooldown
	
	local s = {}
	
	s.name = skill.name
	s.action = skill.action
	s.target = battleScreen.getTarget(skill, player)
	s.effect = skill.effect

	local anim = skill.animation(player, s.target)
	s.sound = anim.snd
	s.image = anim.img
	s.animation = anim.anim
	s.particles = anim.ps
	s.length = anim.len
	s.follower = Follower:new(anim.path, anim.len, anim.xOff, anim.yOff)
	
	s.start = love.timer.getTime()
	
	if s.sound then
		TEsound.play(s.sound, "skillSound")
		TEsound.volume("all", .2)
	end
	
	player.currentSkill = s
	
	s = nil
end

-- enemy turn
function battleScreen.enemyTurn()
	battleScreen.disableBattleMenu()
	
	enemy.inAction = true
	
	local skill = ai.chooseSkill(enemy)
	skill.cdLeft = skill.cooldown
	
	local s = {}
	
	s.name = skill.name
	s.action = skill.action
	s.target = battleScreen.getTarget(skill, enemy)
	s.effect = skill.effect

	local anim = skill.animation(enemy, s.target)
	s.sound = anim.snd
	s.image = anim.img
	s.animation = anim.anim
	s.particles = anim.ps
	s.length = anim.len
	s.follower = Follower:new(anim.path, anim.len, anim.xOff, anim.yOff)
	
	s.start = love.timer.getTime()
	
	if s.sound then
		TEsound.play(s.sound, "skillSound")
		TEsound.volume("all", .2)
	end
	
	enemy.currentSkill = s
	
	s = nil
end

function battleScreen.flee()

end

function battleScreen.getTarget(skill, caster)
	if caster == player then
		if skill.category == "fight" then
			return enemy
		elseif skill.category == "heal" then
			return player
		elseif skill.category == "buff" then
			return player
		end
	elseif caster == enemy then
		if skill.category == "fight" then
			return player
		elseif skill.category == "heal" then
			return enemy
		elseif skill.category == "buff" then
			return enemy
		end
	end
end

return battleScreen