-- the option screen
local optionScreen = {}

-- code to run when option screen is loaded
function optionScreen.load()
	width, height, fullscreen, vsync, fsaa = love.graphics.getMode()
	screenModes = love.graphics.getModes()
	table.sort(screenModes, function(a, b) return a.width*a.height < b.width*b.height end)
	
	optionScreen.initOptionMenu()
end

-- code to run when option screen is destroyed
function optionScreen.unload()
	loveframes.util.RemoveAll()
end

-- code to run when a key is pressed
function optionScreen.keypressed(key, unicode)
end

-- code to run when a key is released
function optionScreen.keyreleased(key, unicode)
end

-- code to run when mouse is pressed
function optionScreen.mousepressed(x, y, button)
end

-- code to run when mouse is released
function optionScreen.mousereleased(x, y, button)
end

-- code to run every frame
function optionScreen.update(dt)
end

-- code to draw every frame
function optionScreen.draw()
	love.graphics.setFont(g_font_dimbo_20)
end

function optionScreen.initOptionMenu()
	optionMenu = {
		loveframes.Create("checkbox"),
		loveframes.Create("multichoice"),
		loveframes.Create("multichoice"),
		loveframes.Create("button"),
		loveframes.Create("button")
	}
	
	optionMenu[1]:SetText("Full Screen")
	optionMenu[1]:SetPos((g_w / 2) - 100, 300)
	if fullscreen then
		optionMenu[1]:SetChecked(true)
	else
		optionMenu[1]:SetChecked(false)
	end
	optionMenu[1].OnChanged = function() end
	
	optionMenu[2]:SetEnabled(false)
	
	optionMenu[2]:SetPos((g_w / 2) - 100, 400)
	--[[for i,v in ipairs(screenModes) do
		optionMenu[2]:AddChoice(v.width .. " x " .. v.height)
	end]]
	
	optionMenu[3]:SetPos((g_w / 2) - 100, 430)
	optionMenu[3]:AddChoice("1X")
	optionMenu[3]:AddChoice("2X")
	optionMenu[3]:AddChoice("4X")
	
	optionMenu[4]:SetText("Cancel")
	optionMenu[4]:SetPos((g_w / 2) - 100, (g_h - 200))
	optionMenu[4]:SetSize(98, 48)
	optionMenu[4]:SetEnabled(true)
	optionMenu[4]:SetClickable(true)
	optionMenu[4].OnClick = function() changeScreen(mainScreen) end
	
	optionMenu[5]:SetText("Save")
	optionMenu[5]:SetPos((g_w / 2), (g_h - 200))
	optionMenu[5]:SetSize(98, 48)
	optionMenu[5].OnClick = function() optionScreen.initConfirmFrame() end
end

function optionScreen.initConfirmFrame()
	local confirmFrame = loveframes.Create("frame")
	confirmFrame:SetName("Confirm Changes?")
	confirmFrame:SetSize(g_w / 4, g_h / 6)
	confirmFrame:SetDraggable(false)
	confirmFrame:Center()
	
	local cancelButton = loveframes.Create("button", confirmFrame)
	cancelButton:SetSize(100, 30)
	cancelButton:SetText("Cancel")
	cancelButton:SetPos((confirmFrame:GetWidth() / 2) - 120, (confirmFrame:GetHeight() / 2) - 10)
	cancelButton.OnClick = function() confirmFrame:Remove() end
	
	local saveButton = loveframes.Create("button", confirmFrame)
	saveButton:SetSize(100, 30)
	saveButton:SetText("Yes")
	saveButton:SetPos((confirmFrame:GetWidth() / 2) + 20, (confirmFrame:GetHeight() / 2) - 10)
	saveButton.OnClick = function() optionScreen.saveOptions() confirmFrame:Remove() end
end

function optionScreen.saveOptions()
	local resChoice = optionMenu[2]:GetChoice()
	local newRes = {}
	for res in resChoice:gmatch("%d+") do table.insert(newRes, res) end
	
	local speedChoice = optionMenu[3]:GetChoice()
	
	local mode = {
		g_w = tonumber(newRes[1]),
		g_h = tonumber(newRes[2]),
		full = optionMenu[1]:GetChecked(),
		vsync = vsync,
		aa = fsaa
	}
	
	g_w = mode.g_w or love.graphics.getWidth()
	g_h = mode.g_h or love.graphics.getHeight()
	
	TLfres.setScreen(mode)
	
	changeScreen(mainScreen)
end

return optionScreen