local skillScreen = {}

function skillScreen.load()
	l_lvl = player.stats.level
	l_sp = player.progress.curSp
	l_skills = deepCopy(player.skills)
	
	skillScreen.initSkillScreen()
end

function skillScreen.unload()
	loveframes.util.RemoveAll()
end

function skillScreen.keypressed(key, unicode)
end

function skillScreen.keyreleased(key, unicode)
end

function skillScreen.mousepressed(x, y, button)
end

function skillScreen.mousereleased(x, y, button)
end

function skillScreen.update(dt)
end

function skillScreen.draw()
	love.graphics.setFont(g_font_dimbo_16)
	love.graphics.print("Skills cost 5 skill points", g_w/8, g_h/8)
	love.graphics.print("Click a skill to purchase", g_w/8, g_h/8+20)
	love.graphics.setFont(g_font_dimbo_24)
	love.graphics.print("Skill Points: " .. l_sp, 130, g_h/1.5)
end

function skillScreen.initSkillScreen()
	saveButton = loveframes.Create("button")
	saveButton:SetText("Save")
	saveButton:SetPos(100, g_h / 1.3)
	saveButton:SetSize(100, 40)
	saveButton.OnClick = function() skillScreen.saveSkills() end
	
	discardButton = loveframes.Create("button")
	discardButton:SetText("Discard")
	discardButton:SetPos(210, g_h / 1.3)
	discardButton:SetSize(100, 40)
	discardButton.OnClick = function() skillScreen.discardSkills() end
	
	backButton = loveframes.Create("button")
	backButton:SetText("Back")
	backButton:SetPos(g_w - 200, g_h / 1.3)
	backButton:SetSize(100, 40)
	backButton.OnClick = function() changeScreen(storyScreen) end
	
	fightSkills = {}
	healSkills = {}
	buffSkills = {}
	
	for i,v in ipairs(skillCatalogue.skills) do
		if v.player then
			local currentSkill = skillCatalogue.lookUp(i)
			local button = loveframes.Create("button")
			local tooltip = loveframes.Create("tooltip")
			
			button:SetText(currentSkill.name)
			button:SetSize(140, 60)
			button.OnClick = 
				function(object) 
					tooltip:Remove()
					skillScreen.buySkill(object, i) 
				end
				
			tooltip:SetObject(button)
			tooltip:SetFollowCursor(false)
			tooltip:SetOffsets(20, -4)
			tooltip:SetPadding(10)
			tooltip:SetTextMaxWidth(220)
			tooltip:SetFont(g_font_sansumi_12)
			tooltip:SetText(currentSkill.description)
			
			if player.progress.curSp < 5 or currentSkill.level > l_lvl then
				button:SetEnabled(false)
			else
				for i,v2 in pairs(l_skills) do
					if v2.index == currentSkill.index then
						button:SetEnabled(false)
					end
				end
			end
			
			if v.category == "fight" then
				table.insert(fightSkills, button)
			elseif v.category == "heal" then
				table.insert(healSkills, button)
			elseif v.category == "buff" then
				table.insert(buffSkills, button)
			end
		end
	end
	
	local buttonY = g_h/1.2
	for i,v in ipairs(fightSkills) do
		v:SetPos(g_w/2 - 260, buttonY)
		
		buttonY = buttonY - 66
	end
	
	local buttonY = g_h/1.2
	for i,v in ipairs(healSkills) do
		v:SetPos(g_w/2 - 70, buttonY)
		
		buttonY = buttonY - 66
	end
	
	local buttonY = g_h/1.2
	for i,v in ipairs(buffSkills) do
		v:SetPos(g_w/2 + 120, buttonY)
		
		buttonY = buttonY - 66
	end
	
	saveButton:SetEnabled(false)
	discardButton:SetEnabled(false)
end

function skillScreen.buySkill(button, i)
	saveButton:SetEnabled(true)
	discardButton:SetEnabled(true)
	
	if l_sp >= 5 then
		button:SetEnabled(false)
		l_sp = l_sp - 5
		table.insert(l_skills, skillCatalogue.lookUp(i))
	end
end

function skillScreen.saveSkills()
	saveButton:SetEnabled(false)
	discardButton:SetEnabled(false)
	
	player.progress.curSp = l_sp
	player.skills = deepCopy(l_skills)
	ai.sortByLevel(player.skills, ">")
	saveGame(player)
	
	skillScreen.unload()
	skillScreen.initSkillScreen()
end

function skillScreen.discardSkills()
	saveButton:SetEnabled(false)
	discardButton:SetEnabled(false)
	
	l_sp = player.progress.curSp
	l_skills = deepCopy(player.skills)
	
	skillScreen.unload()
	skillScreen.initSkillScreen()
end

return skillScreen