Toon = class('Toon')

Player = class('Player', Toon)
Enemy = class('Enemy', Toon)

local progress_box_sprite = love.graphics.newImage("img/other/progress_box.png")
local hp_bar_sprite = love.graphics.newImage("img/other/progress_bar.png")

function Toon:update(dt)
	if self.boon.count > 0 then
		self.boon.visual:setSizes(1 + (self.boon.count * .4),1 + (self.boon.count * .3),1 + (self.boon.count * .2));
		self.boon.visual:setSpeed(76 + (self.boon.count * 20),137 + (self.boon.count * 20));
		self.boon.visual:setEmissionRate(800 + (self.boon.count * 400));
		self.boon.visual:update(dt)
	else
		self.boon.visual:setSizes(1,1,1);
		self.boon.visual:setSpeed(76,137);
		self.boon.visual:setEmissionRate(800);
	end
	
	
	if self.condition.count > 0 then
		if self.condition.val <= 170 then
			self.condition.iter = (self.condition.count * 60) * dt
		elseif self.condition.val >= 250 then
			self.condition.iter = (self.condition.count * 60) * dt * -1
		end
		
		self.condition.val = math.floor(self.condition.val + self.condition.iter)
		
		h = 0
		s = math.max(math.min(self.condition.val, 255), 0)
		l = 128
		a = 255
		
		r, g, b, a = HSL(h, s, l, a)
		
		self.condition.visual = {r, g, b, a}
	else
		self.condition.iter = 0
		self.condition.val = 170
		
		r, g, b, a = HSL(0, 170, 128, 255)
		
		self.condition.visual = {r, g, b, a}
	end
end

function Toon:drawSprite()
	if self.boon.count > 0 then
		love.graphics.draw(self.boon.visual, self:getMiddle().x, self:getMiddle().y, 0, g_sx, g_sy)
	end
	if self.condition.count > 0 then
		love.graphics.setColorMode("combine")
		love.graphics.setColor(self.condition.visual)
	end
	
	love.graphics.draw(self:getSkin(), self:getX(), self:getY(), 0, g_sx, g_sy)
	love.graphics.setColorMode("modulate")
	
	love.graphics.setColor(255, 255, 255, 255)
end

function Toon:drawAction()
	if self.inAction and self.currentSkill then
		local s = self.currentSkill
		
		love.graphics.setColor(255, 204, 11, 255)
		love.graphics.setFont(g_font_dimbo_38)
		love.graphics.printf(s.name, g_w/10, g_h/10, 400, "left")
		
		love.graphics.setColor(255, 255, 255, 255)
		
		if s.image then
			if s.animation then
				s.animation:draw(s.image, s.follower:getX(), s.follower:getY(), 0, g_sx, g_sy)
			else
				love.graphics.draw(s.image, s.follower:getX(), s.follower:getY(), 0, g_sx, g_sy)
			end
		end
		if s.particles then
			love.graphics.draw(s.particles, s.follower:getX(), s.follower:getY(), 0, g_sx, g_sy)
		end
	end
	
	love.graphics.setColor(255, 255, 255, 255)
end

function Toon:drawReport()
	if self.reporting then
		local s = self.currentSkill
		
		love.graphics.setColor(255, 204, 11, 255)
		love.graphics.setFont(g_font_dimbo_38)
		love.graphics.printf(s.name, g_w/10, g_h/10, 400, "left")
		
		if s.target == player then
			love.graphics.draw(arrow, player:getX()+player:getW(), player:getY(), 0, g_sx, -1*g_sy)
		elseif s.target == enemy then
			love.graphics.draw(arrow, enemy:getX(), enemy:getY()+enemy:getH(), 0, -1*g_sx, g_sy)
		end
		
		if skillResult.crit then
			love.graphics.setFont(g_font_dimbo_40)
			love.graphics.printf("Critical Hit!", g_w/2-(g_w/5/2), g_h/2-140, g_w/5, "left")
		elseif skillResult.miss then
			love.graphics.setFont(g_font_dimbo_40)
			love.graphics.printf("Miss!", g_w/2-(g_w/5/2), g_h/2-140, g_w/5, "left")
		end
		
		if not skillResult.miss then
			love.graphics.setFont(g_font_dimbo_36)
			local line_h = -18
			for i,v in ipairs(skillResult.status) do
				love.graphics.printf(v, g_w/2-(g_w/5/2), g_h/2+line_h, g_w/5, "right")
				line_h = line_h+42
			end
			
			if skillResult.category == "fight" then
				love.graphics.setColor(222, 22, 22, 255)
			elseif skillResult.category == "heal" then
				love.graphics.setColor(22, 222, 22, 255)
			elseif skillResult.category == "buff" then
				love.graphics.setColor(22, 22, 222, 255)
			end
			
			love.graphics.setFont(g_font_dimbo_100)
			if skillResult.result then
				love.graphics.printf(skillResult.result, g_w/2-(g_w/5/2), g_h/2-110, g_w/5, "center")
			end
		end
		
		if effectResult then
			love.graphics.setFont(g_font_dimbo_36)
			
			local l_x, l_y = self:getX(), self:getY()
			
			if self == player then
				l_x = l_x - 20
				l_y = l_y + 40
			elseif self == enemy then
				l_x = l_x - 100
				l_y = l_y + (40 * g_sy)
			end
			
			love.graphics.setColor(22, 222, 22, 255)
			for _,v in pairs(effectResult.hots) do
				love.graphics.printf("+" .. v, l_x, l_y, 100, "right")
				l_y = l_y - 33
			end
			
			love.graphics.setColor(222, 22, 22, 255)
			for _,v in pairs(effectResult.dots) do
				love.graphics.printf("-" .. v, l_x, l_y, 100, "right")
				l_y = l_y - 33
			end
		end
	end
	
	love.graphics.setColor(255, 255, 255, 255)
end

function Player:drawHUD()
	local status = ""
	for _,v in pairs(self.activeEffects) do
		if status == "" then
			status = status .. v.name .. " (" .. v.dLeft .. ")"
		else
			status = status .. ", " .. v.name .. " (" .. v.dLeft .. ")"
		end
	end
	
	local prog_box_w = progress_box_sprite:getWidth() * g_sx
	local prog_box_h = progress_box_sprite:getHeight() * g_sy
	local prog_box_x = self:getX() + self:getW() + (100 * g_sx)
	local prog_box_y = self:getY() + (self:getH() / 3)
	
	local fill_box_w = prog_box_w - (8 * g_sx)
	local fill_box_h = prog_box_h - (8 * g_sy)
	local fill_box_x = prog_box_x + ((prog_box_w - fill_box_w) / 2)
	local fill_box_y = prog_box_y + ((prog_box_h - fill_box_h) / 2)
	
	local percent_xp = self.progress.curXp / self.progress.xpToLvl
	local part_fill_box_h = math.ceil(percent_xp * fill_box_h)
	local part_fill_box_y = fill_box_y + (fill_box_h - part_fill_box_h)
	
	local hp_bar_w = hp_bar_sprite:getWidth() * g_sx
	local hp_bar_h = hp_bar_sprite:getHeight() * g_sx
	local hp_bar_x = prog_box_x + prog_box_w + (10 * g_sx)
	local hp_bar_y = prog_box_y + (20 * g_sx)
	
	local hp_fill_bar_w = hp_bar_w - (8 * g_sx)
	local hp_fill_bar_h = hp_bar_h - (8 * g_sy)
	local hp_fill_bar_x = hp_bar_x + ((hp_bar_w - hp_fill_bar_w) / 2)
	local hp_fill_bar_y = hp_bar_y + ((hp_bar_h - hp_fill_bar_h) / 2)
	
	local percent_hp = self.state.curHp / self.state.totHp
	local part_hp_fill_bar_w = math.ceil(percent_hp * hp_fill_bar_w)
	
	local status_w = g_w - prog_box_x - 20
	local status_x = prog_box_x
	local status_y = g_h - (60 * g_sy)
	local status_align = "left"
	
	love.graphics.setColor(60, 60, 60, 255)
	love.graphics.rectangle("fill", fill_box_x, fill_box_y, fill_box_w, fill_box_h)
	love.graphics.setColor(0, 102, 174, 255)
	love.graphics.rectangle("fill", fill_box_x, part_fill_box_y, fill_box_w, part_fill_box_h)
	love.graphics.draw(progress_box_sprite, prog_box_x, prog_box_y, 0, g_sx, g_sy)
	love.graphics.setColor(255, 255, 255, 255)
	love.graphics.setFont(g_font_dimbo_78)
	love.graphics.printf(self.stats.level, fill_box_x - (8 * g_sx), fill_box_y, fill_box_w, "center")
	
	love.graphics.setColor(60, 60, 60, 255)
	love.graphics.rectangle("fill", hp_fill_bar_x, hp_fill_bar_y, hp_fill_bar_w, hp_fill_bar_h)
	love.graphics.setColor(200, 30, 30, 255)
	love.graphics.rectangle("fill", hp_fill_bar_x, hp_fill_bar_y, part_hp_fill_bar_w, hp_fill_bar_h)
	love.graphics.draw(hp_bar_sprite, hp_bar_x, hp_bar_y, 0, g_sx, g_sy)
	love.graphics.setColor(255, 255, 255, 255)
	love.graphics.setFont(g_font_dimbo_38)
	love.graphics.printf(self.state.curHp .. " / " .. self.state.totHp, hp_fill_bar_x, hp_fill_bar_y, hp_fill_bar_w, "center")
	
	love.graphics.setColor(255, 204, 11, 255)
	love.graphics.setFont(g_font_dimbo_26)
	love.graphics.printf(status, status_x, status_y, status_w, status_align)
	
	love.graphics.setColor(255, 255, 255, 255)
end

function Enemy:drawHUD()
	local l_sxy = 0.625
	
	local status = ""
	for _,v in pairs(self.activeEffects) do
		if status == "" then
			status = status .. v.name .. " (" .. v.dLeft .. ")"
		else
			status = status .. ", " .. v.name .. " (" .. v.dLeft .. ")"
		end
	end
		
	local prog_box_w = progress_box_sprite:getWidth() * g_sx * l_sxy
	local prog_box_h = progress_box_sprite:getHeight() * g_sy * l_sxy
	local prog_box_x = self:getX() - prog_box_w - (140 * g_sx)
	local prog_box_y = 100 * g_sy
	
	local fill_box_w = prog_box_w - (8 * g_sx * l_sxy)
	local fill_box_h = prog_box_h - (8 * g_sy * l_sxy)
	local fill_box_x = prog_box_x + ((prog_box_w - fill_box_w) / 2)
	local fill_box_y = prog_box_y + ((prog_box_h - fill_box_h) / 2)
	
	local percent_xp = 0
	local part_fill_box_h = math.ceil(percent_xp * fill_box_h)
	local part_fill_box_y = fill_box_y + (fill_box_h - part_fill_box_h)
	
	local hp_bar_w = hp_bar_sprite:getWidth() * g_sx * l_sxy
	local hp_bar_h = hp_bar_sprite:getHeight() * g_sx * l_sxy
	local hp_bar_x = prog_box_x - hp_bar_w - (10 * g_sx * l_sxy)
	local hp_bar_y = prog_box_y + (20 * g_sx * l_sxy)
	
	local hp_fill_bar_w = hp_bar_w - (8 * g_sx * l_sxy)
	local hp_fill_bar_h = hp_bar_h - (8 * g_sy * l_sxy)
	local hp_fill_bar_x = hp_bar_x + ((hp_bar_w - hp_fill_bar_w) / 2)
	local hp_fill_bar_y = hp_bar_y + ((hp_bar_h - hp_fill_bar_h) / 2)
	
	local percent_hp = self.state.curHp / self.state.totHp
	local part_hp_fill_bar_w = math.ceil(percent_hp * hp_fill_bar_w)
	
	local status_w = prog_box_x + prog_box_w - 20
	local status_x = prog_box_x + prog_box_w - (status_w)
	local status_y = (10 * g_sy)
	local status_align = "right"
	
	love.graphics.setColor(60, 60, 60, 255)
	love.graphics.rectangle("fill", fill_box_x, fill_box_y, fill_box_w, fill_box_h)
	love.graphics.draw(progress_box_sprite, prog_box_x, prog_box_y, 0, g_sx * l_sxy, g_sy * l_sxy)
	love.graphics.setColor(255, 255, 255, 255)
	love.graphics.setFont(g_font_dimbo_48)
	love.graphics.printf(self.stats.level, fill_box_x - (8 * g_sx * l_sxy), fill_box_y, fill_box_w, "center")
	
	love.graphics.setColor(60, 60, 60, 255)
	love.graphics.rectangle("fill", hp_fill_bar_x, hp_fill_bar_y, hp_fill_bar_w, hp_fill_bar_h)
	love.graphics.setColor(200, 30, 30, 255)
	love.graphics.rectangle("fill", hp_fill_bar_x, hp_fill_bar_y, part_hp_fill_bar_w, hp_fill_bar_h)
	love.graphics.draw(hp_bar_sprite, hp_bar_x, hp_bar_y, 0, g_sx * l_sxy, g_sy * l_sxy)
	love.graphics.setColor(255, 255, 255, 255)
	love.graphics.setFont(g_font_dimbo_24)
	love.graphics.printf(self.state.curHp .. " / " .. self.state.totHp, hp_fill_bar_x, hp_fill_bar_y, hp_fill_bar_w, "center")
	
	love.graphics.setColor(255, 204, 11, 255)
	love.graphics.setFont(g_font_dimbo_18)
	love.graphics.printf(status, status_x, status_y, status_w, status_align)
	
	love.graphics.setColor(255, 255, 255, 255)
end

function Toon:addEffect(caster, effect)
	if effect.category == "buff" then
		effect.dLeft = effect.duration + 1
	else
		effect.dLeft = effect.duration
	end
	effect.caster = caster
	
	if effect.kind == "boon" then
		effect.points = effect.action(effect.caster, self)
		
		if self.boon.count == 0 then
			self.boon.visual:start()
		end
		self.boon.count = self.boon.count + 1
	elseif effect.kind == "condition" then
		effect.points = effect.action(effect.caster, self)
		self.condition.count = self.condition.count + 1
	end
	
	table.insert(self.activeEffects, effect)
	
	return effectResult
end

function Toon:refreshStatus()
	self.inAction 		= false
	self.reporting 		= false
	self.currentSkill 	= {}
	
	for k,v in pairs(self.activeEffects) do
		v.remove(self, v.points)
	end
	
	self.activeEffects = {}
	
	self.boon.count = 0
	self.boon.visual:setSpeed(76,137);
	self.boon.visual:setEmissionRate(658 + (self.boon.count * 200));
	
	self.condition.count = 0
	self.condition.iter = 0
	self.condition.val = 0
	self.condition.visual = {0, 0, 0, 0}
	
	for k,v in pairs(self.skills) do
		v.cdLeft = 0
	end
end

function Toon:updateStatus()
	local effects = {
		hots = {},
		dots = {},
	}
	
	for k,v in pairs(self.skills) do
		if v.cdLeft > 0 then
			v.cdLeft = v.cdLeft - 1
		end
	end
	
	for k,v in pairs(self.activeEffects) do
		if v.dLeft > 0 then
			v.dLeft = v.dLeft - 1
		end
		
		if v.dLeft < v.duration and v.ot then
			v.points = v.action(v.caster, self)
			
			if v.kind == "hot" then
				effects.hots[v.name] = v.points
			elseif v.kind == "dot" then
				effects.dots[v.name] = v.points
			end
		end
		
		if v.dLeft == 0 then
			v.remove(self, v.points)
			self.activeEffects[k] = nil
			
			if v.kind == "boon" then
				self.boon.count = self.boon.count - 1
				if self.boon.count == 0 then
					self.boon.visual:stop()
				end
			end
			if v.kind == "condition" then
				self.condition.count = self.condition.count - 1
			end
		end
	end
	
	return effects
end

function Toon:getSkin()
	return self.entity.skin
end

function Toon:getDimensions()
	return deepCopy(self.entity.dim)
end

function Toon:getW()
	return self.entity.dim.w
end

function Toon:getH()
	return self.entity.dim.h
end

function Toon:getPosition()
	return deepCopy(self.entity.pos)
end

function Toon:getX()
	return self.entity.pos.x
end

function Toon:getY()
	return self.entity.pos.y
end

function Toon:getCenter()
	return deepCopy(self.entity.center)
end

function Toon:getSky()
	return deepCopy(self.entity.sky)
end

function Toon:getMiddle()
	return deepCopy(self.entity.middle)
end

function Toon:getMouth()
	return deepCopy(self.entity.mouth)
end

function Toon:getHand()
	return deepCopy(self.entity.hand)
end

function Toon:getFoot()
	return deepCopy(self.entity.foot)
end

-- Player constructor
function Player:initialize(playerData)
	-- set player's data 
	self.name 			= playerData.name
	self.inAction 		= false
	self.reporting 		= false
	self.currentSkill 	= {}
	
	self.boon = {}
	self.boon.count = 0
	self.boon.visual = love.graphics.newParticleSystem(love.graphics.newImage("img/particle/particle_2.png"), 250)
		self.boon.visual:setBufferSize(1062);
		self.boon.visual:setColors(255,255,255,255,105,198,255,72);
		self.boon.visual:setDirection(6.2831852);
		self.boon.visual:setOffset(0,0);
		self.boon.visual:setEmissionRate(800);
		self.boon.visual:setGravity(0,0);
		self.boon.visual:setLifetime(-1);
		self.boon.visual:setParticleLife(0.59,1.4);
		self.boon.visual:setRadialAcceleration(0,0);
		self.boon.visual:setRotation(0,0);
		self.boon.visual:setSizes(1,1,1);
		self.boon.visual:setSpeed(76,137);
		self.boon.visual:setSpin(0,0);
		self.boon.visual:setSpread(6.2831852);
		self.boon.visual:setTangentialAcceleration(0,0);
		self.boon.visual:stop();
	
	self.condition = {}
	self.condition.count = 0
	self.condition.iter = 0
	self.condition.val = 170
	r, g, b, a = HSL(0, 170, 128, 255)
	self.condition.visual = {r, g, b, a}
	
	self.entity		= {}
	self.entity.skin 	= love.graphics.newImage("img/character/badger_back.png")
	self.entity.dim 	= {w=self.entity.skin:getWidth()*g_sx, h=self.entity.skin:getHeight()*g_sy}
	self.entity.pos 	= {x=0, y=0}
	self.entity.center 	= {x=0, y=0}
	self.entity.sky		= {x=0, y=0}
	self.entity.middle	= {x=0, y=0}
	self.entity.mouth 	= {x=0, y=0}
	self.entity.hand 	= {x=0, y=0}
	self.entity.foot	= {x=0, y=0}
	
	self.stats 		= {
		level 			= playerData.stats.level,
		hp 				= playerData.stats.hp,
		attack 			= playerData.stats.attack,
		defense 		= playerData.stats.defense,
		intelligence	= playerData.stats.intelligence,
		speed 			= playerData.stats.speed,
		accuracy 		= playerData.stats.accuracy,
		evasion 		= playerData.stats.evasion,
		critChance 		= playerData.stats.critChance,
		critStrike 		= playerData.stats.critStrike
	}
	
	self.state 		= {
		curHp 			= playerData.stats.hp,
		totHp 			= playerData.stats.hp,
		curAttack 		= playerData.stats.attack,
		curDefense 		= playerData.stats.defense,
		curIntelligence	= playerData.stats.intelligence,
		curSpeed 		= playerData.stats.speed,
		curAccuracy 	= playerData.stats.accuracy,
		curEvasion 		= playerData.stats.evasion,
		curCritChance 	= playerData.stats.critChance,
		curCritStrike 	= playerData.stats.critStrike,
	}
	
	self.progress 	= {
		curXp 			= playerData.progress.curXp,
		totXp 			= playerData.progress.totXp,
		xpToLvl 		= playerData.progress.xpToLvl,
		curSp			= playerData.progress.curSp,
		totSp			= playerData.progress.totSp,
		nextMob 		= playerData.progress.nextMob,
		mobsKilled 		= playerData.progress.mobsKilled
	}
	
	self.skills 		= playerData.skills
	ai.sortByLevel(self.skills, ">")
	
	self.activeEffects 	= playerData.activeEffects
end

function Player:initPosition()
	self:setPosition(100, g_h - self:getH())
end

function Player:setPosition(x, y)
	self.entity.pos.x = x
	self.entity.pos.y = y
	
	self.entity.center.x = x + self.entity.dim.w/2
	self.entity.center.y = y + self.entity.dim.h/2
	
	self.entity.sky.x = self.entity.center.x
	self.entity.sky.y = 0
	
	self.entity.middle.x = x + (230 * g_sx)
	self.entity.middle.y = y + (170 * g_sy)
	
	self.entity.mouth.x = x + (350 * g_sx)
	self.entity.mouth.y = y + (32 * g_sy)
	
	self.entity.hand.x = x + (420 * g_sx)
	self.entity.hand.y = y + (120 * g_sy)
	
	self.entity.foot.x = self.entity.center.x
	self.entity.foot.y = y + self.entity.dim.h
end

-- update player stats on level up
function Player:levelUp()
	for k,v in pairs(self.activeEffects) do
		v.remove(self, v.points)
	end
	
	self.stats.level = self.stats.level + 1
	self.stats.hp = math.ceil(self.stats.hp * 1.1)
	self.stats.attack = math.ceil(self.stats.attack * 1.1)
	self.stats.defense = math.ceil(self.stats.defense * 1.1)
	
	if (self.stats.level % 3)  == 0 then
		self.stats.accuracy = math.ceil(self.stats.accuracy * 1.1)
		self.stats.intelligence = math.ceil(self.stats.intelligence * 1.1)
		self.stats.critChance = math.ceil(self.stats.critChance * 1.1)
	end
	if (self.stats.level % 5) == 0 then
		self.stats.speed = math.ceil(self.stats.speed * 1.1)
		self.stats.evasion = math.ceil(self.stats.evasion * 1.1)
	end
	if (self.stats.level % 8) == 0 then
		self.stats.critStrike = math.ceil(self.stats.critStrike * 1.1)
	end
	
	self.progress.xpToLvl = math.ceil(self.progress.xpToLvl * 1.85)
	self.progress.curSp = self.progress.curSp + 3
	self.progress.totSp = self.progress.totSp + 3
	
	self.state.totHp = self.stats.hp
end

-- Enemy constructor
function Enemy:initialize(index)
	-- set enemy data from mobCatalogue
	self.index 			= index
	self.name 			= mobCatalogue[index].name
	self.inAction 		= false
	self.reporting 		= false
	self.currentSkill 	= {}
	
	self.boon = {}
	self.boon.count = 0
	self.boon.visual = love.graphics.newParticleSystem(love.graphics.newImage("img/particle/particle_2.png"), 250)
		self.boon.visual:setBufferSize(1062);
		self.boon.visual:setColors(255,255,255,255,105,198,255,72);
		self.boon.visual:setDirection(6.2831852);
		self.boon.visual:setOffset(0,0);
		self.boon.visual:setEmissionRate(800);
		self.boon.visual:setGravity(0,0);
		self.boon.visual:setLifetime(-1);
		self.boon.visual:setParticleLife(0.59,1.4);
		self.boon.visual:setRadialAcceleration(0,0);
		self.boon.visual:setRotation(0,0);
		self.boon.visual:setSizes(1,1,1);
		self.boon.visual:setSpeed(76,137);
		self.boon.visual:setSpin(0,0);
		self.boon.visual:setSpread(6.2831852);
		self.boon.visual:setTangentialAcceleration(0,0);
		self.boon.visual:stop();
	
	self.condition = {}
	self.condition.count = 0
	self.condition.val = 170
	r, g, b, a = HSL(0, 170, 128, 255)
	self.condition.visual = {r, g, b, a}
	
	self.entity		= {}
	self.entity.skin 	= mobCatalogue[index].skin
	self.entity.dim 	= {w=self.entity.skin:getWidth()*g_sx, h=self.entity.skin:getHeight()*g_sy}
	self.entity.pos 	= {x=0, y=0}
	self.entity.center 	= {x=0, y=0}
	self.entity.sky		= {x=0, y=0}
	self.entity.middle	= {x=0, y=0}
	self.entity.mouth 	= {x=0, y=0}
	self.entity.hand 	= {x=0, y=0}
	self.entity.foot	= {x=0, y=0}
	
	self.stats 		= {
		level 			= mobCatalogue[index].stats.level,
		hp				= mobCatalogue[index].stats.hp,
		attack 			= mobCatalogue[index].stats.attack,
		defense 		= mobCatalogue[index].stats.defense,
		intelligence	= mobCatalogue[index].stats.intelligence,
		speed 			= mobCatalogue[index].stats.speed,
		accuracy 		= mobCatalogue[index].stats.accuracy,
		evasion 		= mobCatalogue[index].stats.evasion,
		critChance 		= mobCatalogue[index].stats.critChance,
		critStrike 		= mobCatalogue[index].stats.critStrike
	}
	
	self.state 		= {
		totHp 			= mobCatalogue[index].stats.hp,
		curHp 			= mobCatalogue[index].stats.hp,
		curAttack 		= mobCatalogue[index].stats.attack,
		curDefense 		= mobCatalogue[index].stats.defense,
		curIntelligence	= mobCatalogue[index].stats.intelligence,
		curSpeed 		= mobCatalogue[index].stats.speed,
		curAccuracy 	= mobCatalogue[index].stats.accuracy,
		curEvasion 		= mobCatalogue[index].stats.evasion,
		curCritChance 	= mobCatalogue[index].stats.critChance,
		curCritStrike 	= mobCatalogue[index].stats.critStrike
	}

	self.xp 			= mobCatalogue[index].xp
	
	self.skills 		= mobCatalogue[index].skills
	
	self.activeEffects 	= {}
end

function Enemy:initPosition(boss)
	if boss then
		self:setPosition(g_w - 440, 40)
	else
		self:setPosition(g_w - 400, 140)
	end
end

function Enemy:setPosition(x, y)
	self.entity.pos.x = x
	self.entity.pos.y = y
	
	self.entity.center.x = x + self.entity.dim.w/2
	self.entity.center.y = y + self.entity.dim.h/2
	
	self.entity.sky.x = self.entity.center.x
	self.entity.sky.y = 0
	
	self.entity.middle.x = x + (mobCatalogue[self.index].middle.x * g_sx)
	self.entity.middle.y = y + (mobCatalogue[self.index].middle.y * g_sy)
	
	self.entity.mouth.x = x + (mobCatalogue[self.index].mouth.x * g_sx)
	self.entity.mouth.y = y + (mobCatalogue[self.index].mouth.y * g_sy)
	
	self.entity.hand.x = x + (mobCatalogue[self.index].hand.x * g_sx)
	self.entity.hand.y = y + (mobCatalogue[self.index].hand.y * g_sy)
	
	self.entity.foot.x = self.entity.center.x
	self.entity.foot.y = y + self.entity.dim.h
end